@@ -1,14 +1,14 @@
-# Copyrights 2001-2020 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2024 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
+# Pod stripped from pm file by OODoc 2.03.
 # This code is part of distribution Mail-Message.  Meta-POD processed with
 # OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
-package Mail::Message::Convert::HtmlFormatText;
-use vars '$VERSION';
-$VERSION = '3.009';
+package Mail::Message::Convert::HtmlFormatText;{
+our $VERSION = '3.016';
+}
 
 use base 'Mail::Message::Convert';
 
@@ -27,9 +27,9 @@ sub init($)
     $self->SUPER::init($args);
 
     $self->{MMCH_formatter} = HTML::FormatText->new
-     ( leftmargin  => (defined $args->{leftmargin}  ? $args->{leftmargin}  : 3)
-     , rightmargin => (defined $args->{rightmargin} ? $args->{rightmargin} : 72)
-     );
+      ( leftmargin  => $args->{leftmargin}  //  3,
+      , rightmargin => $args->{rightmargin} // 72,
+      );
       
     $self;
 }
